import type { SupervisorPublished } from '../views/project/yw/lowCode/sqlAmis/types';

/**
 * mitt 事件类型定义
 *
 * @method openSetingsDrawer 打开布局设置弹窗
 * @method restoreDefault 分栏布局，鼠标移入、移出数据显示
 * @method setSendColumnsChildren 分栏布局，鼠标移入、移出菜单数据传入到 navMenu 下的菜单中
 * @method setSendClassicChildren 经典布局，开启切割菜单时，菜单数据传入到 navMenu 下的菜单中
 * @method getBreadcrumbIndexSetFilterRoutes 布局设置弹窗，开启切割菜单时，菜单数据传入到 navMenu 下的菜单中
 * @method layoutMobileResize 浏览器窗口改变时，用于适配移动端界面显示
 * @method openOrCloseSortable 布局设置弹窗，开启 TagsView 拖拽
 * @method openShareTagsView 布局设置弹窗，开启 TagsView 共用
 * @method onTagsViewRefreshRouterView tagsview 刷新界面
 * @method onCurrentContextmenuClick tagsview 右键菜单每项点击时
 */
declare type MittType<T = any> = {
	// key 为事件名；value 为传参类型
	openSetingsDrawer?: string;
	restoreDefault?: string;
	setSendColumnsChildren: T;
	setSendClassicChildren: T;
	getBreadcrumbIndexSetFilterRoutes?: string;
	layoutMobileResize: T;
	openOrCloseSortable?: string;
	openShareTagsView?: string;
	onTagsViewRefreshRouterView?: T;
	onCurrentContextmenuClick?: T;
	refreshTestStandard?: T;
	refreshTestGrade?: T;
	x6CellPropertyChange?: T;
	x6ViewPropertyChange?: T;
	refreshFaultGroup?: T;
	refreshFault?: T;
	refreshMethodDefinition?: T;
	// 更新故障事件 contentName
	updateFaultContentName: T;
	// 打开故障特征抽屉，传 orgID过去
	openFaultFaceDrawer: any;
	// 关闭指定路由 tagView
	closeTagView: any;

	//#region
	// 管理界面与使用界面的数据同步
	// key 注意命名规范，eg: 'basic.sys.flag.update'
	// 一般包含
	// 1）数据删除（delete）；
	// 2）数据修改（update）；
	// 3）数据添加（insert）；
	// 4）数据排序修改（updateSorter）
	'basic.sys.module.update': {
		ID?: string;
	};
	'basic.sys.type.update': {
		ExtendType: ExtendTypeEnum;
	};
	'basic.sys.flag.update': {
		SysType: string;
	};
	'monitor.point.update': {
		BelongID: string;
		GroupID: string;
		ID?: string;
	};
	'assets.equipment.cost.type.update': {
		ID?: string;
	};
	'assets.equipment.modify.type.update': {
		ID?: string;
	};
	'fault.diagnosis.event.update': {
		ID?: string;
		OldCatalogID?: string;
		CatalogID?: string;
	};

	'supervisor.publish': {
		id: string;
		published: SupervisorPublished;
	};

	//#endregion
};

// mitt 参数类型定义
declare type LayoutMobileResize = {
	layout: string;
	clientWidth: number;
};

// mitt 参数菜单类型
declare type MittMenu = {
	children: RouteRecordRaw[];
	item?: RouteItem;
};
